@@ -202,7 +202,7 @@ int dminstance::in(DataBuffer *d, Socket *sock, Socket *peersock, class HTTPHead
             // grab a block of input, doubled each time
 
             if (rc <= 0) {
-                break; // an error occured so end the while()
+                break; // an error occurred so end the while()
                 // or none received so pipe is closed
             } else {
                 bytesremaining -= rc;
